<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he_IL">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>לחץ כאן כדי לחזור ליישום</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>הורדות</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>ניקוי</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 פריטים</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>נסה שנית</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>עצור</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>פתח</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>פרסם פודקסט ביוטיוב</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>מחבר</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>לוח</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>מסמכים</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>סטילוס</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>רקעים</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>החלף רקע</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>חזרה על הפעולה</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>הקודם</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>דף קודם</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>דף אחד כלפי מעלה</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>הבא</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>הדף הבא</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>דף אחד כלפי מטה</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>נהל מסמכים</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>גלישה באינטרנט</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>שורה</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>שורה קטנה</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>שורה בינונית</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>שורה גדולה</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation>מחק קטן</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>מחק בינוני</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>מחק גדול</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>צבע</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>חזרה</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>קדימה</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>טען מחדש</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>טען מחדש דף זה</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>דף הבית</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>טען את דף הבית</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>סימניות</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>הצג סימניות</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>סימניות</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>הוסף סימניה</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>הצג לוח</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>מחק תוכן</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>הצג העדפות</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>ספרייה</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>הצג ספרייה</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>הצג שולחן עבודה</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>הצג את שולחן העבודה של המחשב</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>גדול יותר</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>הגדלה</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>קטן יותר</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>הקטנה</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>תיקיה חדשה</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>יצור תיקיה חדשה</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>מסמך חדש</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>צור מסמך חדש</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>ייבוא</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>ייבא  מסמך</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>ייצוא</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>ייצא מסמך</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>פתח ב- Board</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>פתח את הדף ב- Board</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>שכפל</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>שכפל את התוכן המסומן</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>מחק תוכן מסומן</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>הוסף למסמך העבודה</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>הוסף את התוכן המסומן למסמך הפתוח</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>הוסף תוכן למסמך</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שנה שם</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>שנה שם התוכן</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>כלים</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>הצג כלים</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>רב מסכים</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>ממדים רחבים )16/9(</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>השתמש במימדים הרחבים של המסמך )16/9(</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>מימדים רגילים )4/3(</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>השתמש במימדים הרגילים של המסמך )4/3(</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>התאם מימדים</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>השתמש במימדי המסמך המותאמים</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>הפסק טעינה</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>הפסק את טעינת דף האינטרנט</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>חתוך</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>העתק</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>הדבק</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>מצב שינה</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>העבר את המצגת למצב שינה</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>מקלדת וירטואלית</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>הצג מקלדת וירטואלית</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>רקע בהיר פשוט</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>בהיר</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>רקע אחיד בהיר</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>רקע אחיד כהה</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>כהה</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>רקע רשת כהה</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>פודקסט</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>הקלט את המצגת לווידאו</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>הקלט</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>התחל להקליט מסך</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>מחק פריטים</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>מחק את כל הפריטים</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>מחק הסברים</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>מחק את כל ההסברים</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>נקה דף</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>נקה את כל המרכיבים</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>עט</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>הוסף למסמך הערות</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>מחק הערות</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>סמן</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>האר</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>בוחר</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>בחר ושנה עצמים</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>יד</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>גלל דף</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>מצביע לייזר</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>מצביע לייזר וירטואלי</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>שרטט קווים</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>טקסט</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>כתוב טקסט</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>לכידה</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>לכד חלק מהמסך</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>הוסף לדף הנוכחי</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>הוסף פריט לדף הנוכחי</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>הוסף לדף חדש</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>הוסף פריט לדף חדש</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>הוסף לספריה</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>הוסף פריט לספריה</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>דפים</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>צור דף חדש</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>דף חדש</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>שכפל דף</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>שכפל את הדף הנוכחי</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>ייבא דף</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>ייבא דף חיצוני</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>השהייה</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>השהה הקלטת הפודקסט</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>קבע תצורת פודקסט</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>קבע תצורת הקלטת הפודקסט</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>מלכודת פלאש</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>תוכן מלכודת פלאש</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>מלכודת אינטרנט</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>לכד תוגן אינטרנט</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>קבע תצורת לכידה</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>לכידת חלון</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>לכד חלון</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>שלב תוכן אינטרנט</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>לכד תוכן אינטרנט מוכנס</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>הראה על המסך</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>הצג את המסך המרכזי על מסך התצוגה</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>מחק את כל ההערות</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>ייבא את הסימולציה של EduMedia</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>בדוק עדכונים</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>הגרסה הפתוחה של Sankoré</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>יציאה מהגרסה הפתוחה של  Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>הסתר את הגרסה הפתוחה של Sankoré</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>הסתר את היישום של הגרסה הפתוחה של Sankoré</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>נגן</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translatorcomment>There is no direct translation of this sentence- please provide contexte</translatorcomment>
        <translation type="unfinished">לתפעל את הפריט</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>מחק רקע</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>הסר רקע</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>נדרש זיהוי</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם משתמש</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמא</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>זיהוי פרוקסי</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>התחבר לפרוקסי</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם  משתמש</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>סיסמא</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>שמור את שם המשתמש והסיסמא לשימוש עתידי</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>זהות הרכיב:</translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>התוכן אינו נתמך בפורמט היעד</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>הסר את הדף</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>האם אתה בטוח שברצונך למחוק דף 1 מהמסמך שנבחר %0?</translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>מימדי הדף</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>פודקסט</translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>ישנו עדכון חדש, לעבור לדף האינטרנט?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>אין כל עדכון</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>קיים עדכון</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>עדכון</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>הודרת תוכן %1 נכשלה</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>ההורדה הסתיימה</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>כלי בלתי ידוע מסוג %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>תוכן בלתי ידוע מסוג %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>הוסף פריט</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>הכל )%1(</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">מחק עמוד %1 מהמסמך</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>דף %1 נמחק</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>הוספת פעולת קובץ נכשלה: אירעה שגיאה בהעתקת הקובץ</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>קבץ</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>בטל קיבוץ</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>אירעה שגיאה בהוספת התמונה לספריה</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>תמונה שנלכדה</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>תכונות המטמון</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>צבע:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>צורה:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>מימדים:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>לכד חלק מהמסך</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>לכד את המסך</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>הצג את סרגל הכלים הגראפיים</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>הצג את- Board על מסך משני</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>הצג את שולחן העבודה על מסך משני</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>תיקיה חדשה</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>עמוד %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>הוסף תיקיית תמונות</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>הוסף תמונות</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>הוסף עמודים מהקובץ</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>משכפל מסמך %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>מסמך %1 הועתק</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">הסר את הדף</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">הסר את המסמך</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">אתה בטוח שברצונך להסיר את  %1&apos;המסמך?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">רוקן את הסל</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">אתה בטוח שברצונך לרוקן את הסל?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">מרוקן סל</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">הסל הורק</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">הסר תיקיה</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">אתה בטוח שברצונך להסיר את התיקיה %1 ואת כל תכנה?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">לא נבחר כל מסמך!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>פתח קובץ מתאים</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>מייבא קובץ 1%...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>ייבוא הקובץ נכשל...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>ייבא את כל התמונות מהתיקיה</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>רוקן</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>סל</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>פתח מסמך</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>הוסף את כל התמונות למסמך</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>כל התמונות )%1(</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>בקטע שנבחר אין כל קבצי תמונות!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>האם אתה בטוח שברצונך להסיר %n עמוד(ים) מהמסמך שנבחר %1&apos;?</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>התיקיה אינה מכילה כל קבצי תמונות</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>מסמכים ללא שם</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>תמונות</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>סרטונים</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>אובייקטים</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>ווידג&apos;טים</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>כל הקבצים הנתמכים )*.%1(</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>קובץ %1 נשמר</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>מכניס עמוד %1 מתוך %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>הייבוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>ייבוא קובץ %1 התבצע בהצלחה</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>מייבא קובץ %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>עמוד %0</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">קבל</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">בטל</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">סל</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 דפים הועתקו</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 דפים הועתקו</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">מעתיק עמוד %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (העתק)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">מעתיק עמוד %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 דפים הועתקו</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>מוריד קבצים</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>בטל</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">עמוד %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">עמוד %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings during export was appeared</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>ייצא ל-IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>ייצא כקובץ IWB</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>פעולת הייצוא נכשלה</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>עמוד</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>ייצא כקובץ UBZ</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>מייצא %1 %2 מתוך %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>ייצוא כקובץ PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>ייצא ל- PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>ייצא בתור קובץ PDF</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>מייצא דף %1 מתוך %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>ייצא ל- PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>עמוד</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>ייצא כנתוני אינטרנט</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>מייצא מסמך...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>הייצוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>הייצוא נכשל.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>ייצא לדפדפן </translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>הוסף לדף</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">קבע כרקע</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>הוסף לספרייה</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>מידע על האובייקט</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>הוסף למועדפים</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>שתף</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>חזרה לקובץ</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>הסר מהמועדפים</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>צור תיקייה חדשה</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>סרוק מחדש את מערכת הקבצים</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>תמונה מיובאת</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>קבצי שמע</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>סרטים</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>תמונות</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>אנימציות</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>אינטראקטיביות</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>יישומים</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>צורות</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>מועדפים</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>חיפוש באינטרנט</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>סל</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>קבל</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>בטל</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>הזן שם תיקיה חדש</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>טוען</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>נעול</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>ניתן לראותו במסך רחב</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>נעול</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>ניתן לראותו במסך רחב</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>עבור למקור התוכן</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">קבע כרקע</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;הדפס טקסט כאן&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>צבע הטקסט</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>ניתן לעריכה</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>אינטרנט</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>טוען...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>קפוא</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>הפוך לכלי</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>פורמט קובץ רגיל )</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>מייבא קובץ %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>ייבוא קובץ %1 נכשל.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>הייבוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>הייבוא נכשל.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>מייבא קובץ %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>ייבוא קובץ %1 נכשל.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>הייבוא בוצע בהצלחה.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>פורמט התמונה )</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>ייבוא ה- PDF נכשל.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>מייבא עמוד %1 מתוך %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>אירעה שגיאה במהלך הפצת הוידאו לאינטראנט )%1(</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>מתבצע פרסום לאינטראנט %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>פרסם</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translatorcomment>pour la touche Enter</translatorcomment>
        <translation>מקש ה= ENTER</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>No</source>
        <translation>לא</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;הקש שם משתמש וסיסמא עבור &quot;%1&quot; ו- %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>הכניסה לפרוקסי נכשלה</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>שגיאות SSL %1 %2 האם ברצונך להתעלם משגיאות אלה למארח זה?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>כן</translation>
    </message>
    <message>
        <source>No</source>
        <translation>לא</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">בטל</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(העתק)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>אבד מקום האכסון של המסמך</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>אנגלית</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>רוסית</translation>
    </message>
    <message>
        <source>German</source>
        <translation>גרמנית</translation>
    </message>
    <message>
        <source>French</source>
        <translation>צרפתית</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>צרפתית של שוויץ</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>הפעלת המקדד נכשלה...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>אין כל מקדד זמין לפודקסט...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>רכיב%1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>על שולחן העבודה שלך...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>בתיקיה %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>הפודקסט נוצר %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>שגיאת הקלטה של הפודקסט )%1(</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>קלט אודיו של ברירת מחדל</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>אין כל הקלטת אודיו</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>קטן</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>בינוני</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>מלא</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>פרסם באינטרנט</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>פרסם ביוטיוב</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>גרסא:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>הסמן רגיש ללחץ</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">כניסה לפרוקסי</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">שם משתמש:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">סיסמא:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">פרסם מסמך באינטרנט</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">שם:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">תיאור:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">פרסם</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>הסרטים שלי</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>מייצר תמונה מוקטנת לצפייה מוקדמת...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>נוצרה תמונה מוקטנת של %1...</translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">עמוד %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>תבנית</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>סרגל</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>מצפן</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>מד-זווית</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>משולש</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>זכוכית מגדלת</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>מטמון</translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>דף מלא</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>אינטרנט</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>מעדכן מסמכים</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>הקבצים דורשים עדכון.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>נתיב גיבוי:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>דפדף</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>עדכן</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>בחר תיקיה לגיבוי</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>עדכון הקבצים בוצע בהצלחה!
יש לאתחל את היישום כדי לגשת למסמכים המעודכנים.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>אירעה שגיאה במהלך העדכון. הקבצים לא נפגעו.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>תוצאות עדכון הקבצים</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>מעדכן קובץ</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>אנא המתן תהליך הייבוא עומד להתחיל...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation> לי שוב מאוחר יות</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>טוען...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 נקרא )שיטה=%1, מצב = %2(</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>זיהוי היוטיוב נכשל.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>אירעה שגיאה במהלך טעינת הסרטון ליוטיוב )%1(</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>מעלה ליוטיוב%1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>העלאה</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>מכוניות &amp; כלי רכב</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>מוסיקה</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>חיות מחמד &amp; בעלי חיים</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>ספורט</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>נסיעות  &amp; אירועים</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>משחקים</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>קומדיה</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>אנשים &amp; בלוגים</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>חדשות &amp; פוליטיקה</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>בילוי</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>חינוך</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>עצות &amp; סגנון</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>ארגונים שלא למטרת רווח &amp; אקטיביזם</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>מדע &amp; טכנולוגיה</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>נקה</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>שמור קובץ</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>ההורדה בוטלה: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>אירעה שגיאה בפתיחת הקובץ השמור: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>שגיאה בשמירה: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>שגיאת רשת: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>שניות</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>דקות</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 נשארו</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 מ %2 (%3/שניות) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 מתוך %2 0 מופסק</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>בייטים</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>הורדה 1</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 הורדות</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>כתובת</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>מוקדם יותר היום</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 פריטים</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>חדש &amp; לשונית</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>שכפל לשונית</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;סגור לשונית</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>סגור &amp;לשוניות אחרות </translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>טען מחדש את הלשונית</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>טען מחדש את כל הלשוניות</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>לשוניות שנסגרו לאחרונה</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(ללא שם)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>אין חיפושים שבוצעו לאחרונה</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>חיפושים שבוצעו לאחרונה</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>נקה חיפושים שבוצעו לאחרונה</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>הורד</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>הוסף למסמך הקיים</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>שגיאה בטעינת עמוד: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>פתח בלשונית חדשה</translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>פרסם פודקסט ביוטיוב</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>מילות מפתח</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>קטיגוריה</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>שם המשתמש ליוטיוב</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>הסיסמא ליוטיוב</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">הגרסה הפתוחה של Sankoré</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>על רקע בהיר</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>על רקע כהה</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>אטימות</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>רוחב קו</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>בינוני</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>חזק</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>דק</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>העט רגיש ללחץ</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>דיאלוג</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>שם</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>דואל</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>מחבר</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>תיאור</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">דיאלוג</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">שם</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">דואל</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">מחבר</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">תיאור</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>גרסא:...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>הגדרות ברירת מחדל</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>סגור</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>הצג</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>אינטרנט</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>הצג עמוד עם דפדפן חיצוני</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>דף הבית:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>מקלדת וירטואלית</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">גודל מקשי המקלדת:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>סרגל כלים</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>ממוקם בראש הדף )מומלץ למחשבי לוח(</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>הצג טקסט מתחת לכפתור</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>סרגל הכלים הגראפיים</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>אופקי</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>אנכי</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>עט</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>מרקר</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>רשיונות</translation>
    </message>
    <message>
        <source>About</source>
        <translation>אודות</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>עדכון תכנה</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>בדוק עדכון תוכנה עם הפעלתה</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>רשת</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>הצג את תוכן עמוד האינטרנט הפנימי על מסך משני או על מקרן</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>מצג מרובה</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>החלף מצג בקרה והצג מצג</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>מצב</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>מצב להתחלה:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>לוח</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>שולחן העבודה</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>משתמש פרוקסי:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>סיסמא:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>אשראי</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">על רקע כהה</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">אטימות</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">על רקע בהיר</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>מלכודת פלאש</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>בחר פלאש ללכידה</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>אודות: ריק</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>שם היישום</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>צור יישום</translation>
    </message>
</context>
</TS>
